package com.fs.qw.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.qw.domain.QwIpadServerUser;
import com.fs.qw.param.IPadServerUserParam;
import com.fs.qw.vo.QwIPadServerUserVO;

import java.util.List;

/**
 * ipad用户Service接口
 *
 * @author fs
 * @date 2025-04-29
 */
public interface IQwIpadServerUserService extends IService<QwIpadServerUser>{
    /**
     * 查询ipad用户
     *
     * @param id ipad用户主键
     * @return ipad用户
     */
    QwIpadServerUser selectQwIpadServerUserById(Long id);

    /**
     * 查询ipad用户列表
     *
     * @param qwIpadServerUser ipad用户
     * @return ipad用户集合
     */
    List<QwIpadServerUser> selectQwIpadServerUserList(QwIpadServerUser qwIpadServerUser);

    /**
     * 查询ipad用户列表
     *
     * @param iPadServerUserParam ipad用户
     * @return ipad用户集合
     */
    List<QwIPadServerUserVO> selectIpadServerUserList(IPadServerUserParam iPadServerUserParam);

    /**
     * 新增ipad用户
     *
     * @param qwIpadServerUser ipad用户
     * @return 结果
     */
    int insertQwIpadServerUser(QwIpadServerUser qwIpadServerUser);

    /**
     * 修改ipad用户
     *
     * @param qwIpadServerUser ipad用户
     * @return 结果
     */
    int updateQwIpadServerUser(QwIpadServerUser qwIpadServerUser);

    /**
     * 批量删除ipad用户
     *
     * @param ids 需要删除的ipad用户主键集合
     * @return 结果
     */
    int deleteQwIpadServerUserByIds(Long[] ids);

    /**
     * 删除ipad用户信息
     *
     * @param id ipad用户主键
     * @return 结果
     */
    int deleteQwIpadServerUserById(Long id);

    void deleteQwIpadServerUserByQwUserId(Long id);
}
